<?php

/**
 *  Check it not called directly
 */
if( !defined('ABSPATH') ){
    echo "Hey there, direct access not allowed!";
    exit();
}


/**
 * PureAuth Option Page
 */

function pureauth_saml_configuration()
{

    // Add Menu Page
    add_menu_page(
        __("PureAUTH SAML Configuration", "pureauth-saml"),
        __("PureAUTH SAML", "pureauth-saml"),
        "manage_options",
        "pureauth_saml_configuration",
        "pureauth_saml_configuration_html",
	    get_icon_svg(),
        99
    );

    // Declare option_group for Settings API
    $option_group = "pureauth_saml_configuration";

    // Register setting for Enable or Disable
    register_setting($option_group, "pureauth_saml_is_enabled", array("type" => "boolean"));

    // Add section | Status
    add_settings_section("pureauth_saml_status", "SAML Status", "pureauth_saml_status_section_cb", $option_group);

    // Add fields | Status Section
    add_settings_field('pureauth_saml_enabled',  'Enabled', 'pureauth_saml_enabled_field_cb', $option_group, 'pureauth_saml_status');

    /** #Start Register IdP Configuration Options and Section */

    // Register setting
    register_setting( $option_group, "pureauth_idp_entity_id" );
    register_setting( $option_group, "pureauth_idp_authentication_url" );
    register_setting( $option_group, "pureauth_idp_slo_url" );
    register_setting( $option_group, "pureauth_idp_x509_certificate" );

    // Add Section | IdP Configuration
    add_settings_section( "pureauth_idp_configuration", "Identity Provider Configuration", "pureauth_idp_configuration_section_cb", $option_group );

    // Add Fields | IdP Configuration
	add_settings_field( "pureauth_idp_x509_certificate_field", "X.509 Certificate *", "pureauth_idp_x509_certificate_field_cb", $option_group, "pureauth_idp_configuration" );
	add_settings_field( "pureauth_idp_authentication_url_field", "Authentication URL *", "pureauth_idp_authentication_url_field_cb", $option_group, "pureauth_idp_configuration" );
	add_settings_field( "pureauth_idp_entity_id_field", "IdP Entity ID *", "pureauth_idp_entity_id_field_cb", $option_group, "pureauth_idp_configuration" );

    /** #End Register IdP Configuration Options and Section */

    /** #Start Common Options and Section */

    // Register Setting
    register_setting( $option_group, "pureauth_options_allowed_roles" );

    // Add Section | Options
    add_settings_section( "pureauth_common_options", "Options", "pureauth_common_options_section_cb", $option_group );

    // Add Fields | Options
    add_settings_field( "pureauth_options_allowed_roles_field", "Allowed User Roles", "pureauth_options_allowed_roles_field_cb", $option_group, "pureauth_common_options" );

    /** #End Common Options and Section */

}


/**
 * Callback for pureauth_saml_status_section_cb
 * Section Callback | Settings API
 */

function pureauth_saml_status_section_cb()
{
?>
    <p><?php esc_html_e("Use this checkbox to enable or disable SAML support.");  ?></p>
<?php
}

/**
 * Callback for pureauth_saml_enabled_field_cb
 * Section Field Callback
 */
function pureauth_saml_enabled_field_cb()
{
    $setting = get_option('pureauth_saml_is_enabled');
?>
    <input type="checkbox" name="pureauth_saml_is_enabled" id="pureauth_saml_is_enabled" value="1" <?php if ($setting) {echo "checked='checked'";} else {echo "";} ?>>
    <p class="description">Check this checkbox to enable the SAML support.</p>
<?php
}

/**
 * Callback for pureauth_idp_configuration_section_cb
 * Idp Configuration Section Callback
 */
function pureauth_idp_configuration_section_cb()
{
?>
    <p><?php echo esc_html_e( "Configuration related to IdP.", "pureauth-saml" ); ?></p>
<?php
}

/**
 * Callback for pureauth_idp_entity_id_field_cb
 * Entiry ID field | IdP Configuration Section
 */
function pureauth_idp_entity_id_field_cb()
{
    $setting = get_option( "pureauth_idp_entity_id" );
    ?>
    <input type="text" name="pureauth_idp_entity_id" id="pureauth_idp_entity_id" value="<?php echo $setting; ?>" size="80" required>
    <p class="description">Issuer URL</p>
    <?php
}

/**
 * Callback for pureauth_idp_authentication_url_field_cb
 * SSO URL field | IdP Configuration Section
 */
function pureauth_idp_authentication_url_field_cb()
{
    $setting = get_option( "pureauth_idp_authentication_url" );
    ?>
    <input type="text" name="pureauth_idp_authentication_url" id="pureauth_idp_authentication_url" value="<?php echo $setting; ?>" size="80" required>
    <p class="description">Authentication endpoint of the IdP.</p>
    <?php
}

/**
 * Callback for pureauth_idp_x509_certificate_field_cb
 * X.509 Certificate field | IdP Configuration Section
 */
function pureauth_idp_x509_certificate_field_cb()
{
    $setting = get_option( "pureauth_idp_x509_certificate" );
    ?>
    <textarea name="pureauth_idp_x509_certificate" id="pureauth_idp_x509_certificate" cols="70" rows="12" required><?php echo $setting; ?></textarea>
    <p class="description">Public X.509 Certificate of IdP.</p>
    <?php
}

/**
 * Callback for pureauth_common_options_section_cb
 * Section Callback | Options
 */
function pureauth_common_options_section_cb()
{
    ?>
        <p><?php echo esc_html_e( "Configuration options for PureAUTH.", "pureauth-saml" ); ?></p>
    <?php
}

/**
 * Callback for pureauth_options_allowed_roles_field_cb
 * Allowed User Roles | Options
 */
function pureauth_options_allowed_roles_field_cb()
{
    $setting = get_option('pureauth_options_allowed_roles');
    if( $setting == false ) {
	    $setting = array();
    }
    $wp_roles = new WP_Roles();

    $all_roles = $wp_roles->get_names();

    foreach( $all_roles as $role_value => $role_name )
    {
        ?>
            <label for="pureauth_wp_role_<?php echo $role_value; ?>">
                <input type="checkbox" name="pureauth_options_allowed_roles[]" value="<?php echo $role_value; ?>" id="pureauth_wp_role_<?php echo $role_value; ?>" <?php checked( in_array( $role_value, $setting ), 1 ); ?>>
                <?php echo $role_name; ?>
                <br>
            </label>
        <?php
    }
}

/**
 * Markup for PureAuth SAML Configuration Option Page
 */

function pureauth_saml_configuration_html()
{
    // check user capabilities
    if (!current_user_can('manage_options')) {
        return;
    }
?>
    <div class="wrap">
        <div style="align-items: center;">
            <img style="width: 40px; float: left; clear: both;" src="<?php echo esc_url(plugins_url('assets/icons/pureid_logo.png', dirname(__FILE__))); ?>" alt=""/>
            <h1 style="display: inline-block; margin-left: 16px;"><strong><?php echo esc_html(get_admin_page_title()); ?></strong></h1>
        </div>
	    <?php settings_errors(); ?>
        <div style="margin-top: 32px;">
            <h2>Service Provider Configuration</h2>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row">ACS URL</th>
                        <td>
                            <input type="text" value="<?php echo wp_login_url()."?pureauth-saml-acs"; ?>" readonly size="80">
                            <p class="description">ACS URL endpoint of SP.</p>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
        <form action="options.php" method="post">
            <?php
            settings_fields('pureauth_saml_configuration');
            do_settings_sections('pureauth_saml_configuration');
            submit_button("Save Changes");
            ?>
        </form>
    </div>
<?php
}

/**
 * Returns a base64 URL for the svg for use in the menu.
 */
function get_icon_svg( $base64 = true ) {
	$svg = '<svg xmlns="http://www.w3.org/2000/svg" version="1.0" width="170.000000pt" height="170.000000pt" viewBox="0 0 170.000000 170.000000" preserveAspectRatio="xMidYMid meet">
                <g transform="translate(0.000000,170.000000) scale(0.100000,-0.100000)" fill="#82878c" stroke="none">
                <path d="M721 1560 c-108 -108 -120 -124 -126 -164 -10 -62 11 -99 106 -191 43 -42 79 -83 79 -91 0 -8 -17 -30 -37 -49 l-37 -35 -83 82 -83 83 -26 -27 -26 -26 76 -76 c42 -41 76 -81 76 -88 -1 -18 -46 -68 -62 -68 -7 0 -54 40 -103 90 -95 96 -121 109 -192 95 -29 -5 -61 -31 -160 -128 l-124 -121 113 -113 c127 -127 160 -148 226 -140 40 4 53 13 136 96 50 50 97 91 105 91 7 0 29 -17 47 -37 l34 -37 -120 -121 -121 -121 24 -22 c13 -12 27 -22 31 -22 4 0 58 52 120 115 61 63 114 115 118 115 12 0 68 -58 68 -71 0 -6 -40 -54 -89 -104 -67 -69 -91 -102 -96 -128 -13 -68 1 -95 114 -210 58 -60 114 -113 125 -119 16 -9 36 7 136 107 175 174 177 200 29 350 -49 50 -89 96 -89 104 0 11 55 71 66 71 2 0 40 -36 85 -81 l82 -81 26 26 26 26 -83 83 -82 83 34 37 c18 20 39 37 46 37 7 0 55 -40 105 -89 71 -68 101 -91 129 -97 72 -13 93 -1 226 129 l125 122 -126 122 c-179 173 -206 175 -354 32 -51 -49 -98 -89 -106 -89 -8 1 -26 17 -42 37 l-27 37 252 252 c139 139 256 250 260 248 4 -3 8 -41 8 -85 l0 -79 55 0 55 0 0 175 0 175 -175 0 -175 0 0 -55 0 -55 84 0 c47 0 87 -4 90 -8 3 -5 -111 -124 -252 -265 l-257 -256 -37 35 c-21 19 -38 40 -38 47 0 7 40 53 90 102 96 95 109 121 95 191 -5 29 -30 61 -113 146 -59 61 -115 114 -124 119 -14 8 -40 -13 -137 -111z m219 -70 c63 -63 90 -98 90 -115 0 -16 -28 -51 -92 -115 l-91 -93 -94 95 c-51 52 -93 103 -93 113 0 14 174 205 187 205 2 0 44 -41 93 -90z m-20 -514 c0 -6 -17 -27 -37 -48 l-37 -38 -38 37 c-21 20 -38 42 -38 47 0 6 17 27 37 48 l37 38 38 -37 c21 -20 38 -42 38 -47z m-558 27 c18 -16 62 -57 96 -92 l64 -65 -95 -93 c-52 -51 -102 -93 -112 -93 -10 0 -60 42 -112 92 l-94 93 94 92 c52 51 101 93 110 93 8 0 30 -12 49 -27z m1133 -68 c47 -47 85 -88 85 -92 0 -9 -145 -149 -175 -169 -13 -9 -32 -13 -42 -10 -10 3 -58 45 -106 94 l-87 88 95 93 c82 81 98 92 120 87 14 -4 64 -45 110 -91z m-750 -50 c19 -19 35 -40 35 -48 0 -15 -51 -67 -65 -67 -5 0 -26 17 -47 37 l-38 37 37 38 c20 21 39 38 40 38 2 0 19 -16 38 -35z m277 -2 l38 -37 -37 -38 c-20 -21 -42 -38 -47 -38 -16 0 -66 52 -66 69 0 14 57 81 69 81 3 0 22 -17 43 -37z m-149 -126 c49 -51 49 -51 9 -90 l-38 -37 -38 39 -38 38 32 37 c38 42 44 43 73 13z m67 -327 c50 -50 90 -98 90 -108 0 -25 -10 -37 -102 -129 l-83 -84 -92 94 c-51 52 -93 102 -93 112 0 14 174 205 187 205 2 0 44 -41 93 -90z"/>
                <path d="M20 1495 l0 -175 55 0 54 0 3 118 3 117 117 3 118 3 0 54 0 55 -175 0 -175 0 0 -175z"/>
                <path d="M22 194 l3 -175 170 0 170 0 3 55 3 55 -118 3 -118 3 -3 118 -3 117 -55 0 -54 0 2 -176z"/>
                <path d="M1558 253 l-3 -118 -117 -3 -118 -3 0 -54 0 -55 175 0 175 0 0 175 0 175 -55 0 -54 0 -3 -117z"/>
                </g>
            </svg>';

	if ( $base64 ) {
		//phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.obfuscation_base64_encode -- This encoding is intended.
		return 'data:image/svg+xml;base64,' . base64_encode( $svg );
	}

	return $svg;
}
